@@ -88,6 +88,10 @@ configDialog::configDialog(QSettings *mainSettings, QWidget *mainParent)
     item->setTextAlignment(Qt::AlignCenter);
     item->setEditable(false);
     backendModel->appendRow(item);
+    item = new QStandardItem(tr("Translink - Australia"));
+    item->setTextAlignment(Qt::AlignCenter);
+    item->setEditable(false);
+    backendModel->appendRow(item);
     QMaemo5ValueButton *backendButton = new QMaemo5ValueButton(tr("Databackend"));
     backendButton->setValueLayout(QMaemo5ValueButton::ValueUnderTextCentered);
     backendSelector = new QMaemo5ListPickSelector;
@@ -117,6 +121,9 @@ configDialog::configDialog(QSettings *mainSettings, QWidget *mainParent)
     } else if (backendType == "parserXmlRejseplanenDk") //Denmark
     {
         backendSelector->setCurrentIndex(5);
+    } else if (backendType == "parserTranslink") //Queensland
+    {
+        backendSelector->setCurrentIndex(6);
     } else
     {
        //fallback is bahn.de
@@ -183,6 +190,9 @@ void configDialog::okButtonClicked()
     } else if (backendSelector->currentIndex() == 5)
     {
         settings->setValue("backend", "parserXmlRejseplanenDk");
+    } else if (backendSelector->currentIndex() == 6)
+    {
+        settings->setValue("backend", "parserTranslink");
     } else
     {
         settings->setValue("backend", "parserMobileBahnDe");
