@@ -228,6 +228,42 @@ DetailResultInfo parserMobileBahnDe::getJourneyDetailsData(QString queryUrl)
 
     QString xhtml = filebuffer->buffer();
 
+    //check for closed arrow (Verbundtarif???)
+    int linkpos=xhtml.indexOf("id=\"dtlOpen_link\"");
+    int linkpos_start, linkpos_stop;
+    QString link;
+    linkpos_stop = xhtml.indexOf(">",linkpos);
+    link=xhtml.mid(linkpos,linkpos_stop-linkpos);
+    qDebug() << link;
+
+    if (link.contains("class=\"flaparrow\"")) // if arrow closed reload with open arrow
+    {
+        linkpos_start= link.indexOf("href=")+6;
+        linkpos_stop= link.indexOf("\"",linkpos_start);
+        link=link.mid(linkpos_start, linkpos_stop-linkpos_start);
+        link=link.remove(QRegExp("amp;"));
+        qDebug() << link;
+        url.setUrl(link);
+        http->setHost(url.host(), QHttp::ConnectionModeHttp, url.port() == -1 ? 0 : url.port());
+
+        //filebuffer = new QBuffer();
+
+        if (!filebuffer->open(QIODevice::WriteOnly))
+        {
+            qDebug() << "Can't open Buffer";
+        }
+
+        currentRequestId = http->get(url.path() + "?" + url.encodedQuery(), filebuffer);
+
+        loop.exec();
+
+        filebuffer->close();
+
+        //qDebug() <<filebuffer->buffer();
+
+        xhtml = filebuffer->buffer();
+    }
+
     QDateTime routeStart;
     QDateTime routeEnd;
 
@@ -283,8 +319,12 @@ DetailResultInfo parserMobileBahnDe::getJourneyDetailsData(QString queryUrl)
     DetailResultItem toStationItem;
     QTime lastTime=routeStart.time();
     QDate currentDate=routeStart.date();
+
+    //qDebug() << "data_file: " << xhtml;
+
     while (idx >= 0)
     {
+        qDebug() << "idx:" << idx;
         idx = regexp.indexIn(xhtml, idx);
         qDebug() << "DB Mobile:" << idx;
         if (idx >= 0)
@@ -568,7 +608,8 @@ DetailResultInfo parserMobileBahnDe::getJourneyDetailsData(QString queryUrl)
         }
     }
 
-    regexp = QRegExp("<div class=\"red bold\">(.*)</div>");
+    //regexp = QRegExp("<div class=\"red bold\">(.*)</div>");
+    regexp = QRegExp("<span class=\"red bold\">(.*)</span>");
     regexp.setMinimal(true);
     regexp.indexIn(xhtml);
 
